==> sdx-2.2.1-src.zip: sdx-2.2.1/src/java/fr/gouv/culture/sdx/oai/LuceneDocumentBaseOAIHarvester.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.oai;

import fr.gouv.culture.sdx.documentbase.LuceneDocumentBase;

/**
 * Created by IntelliJ IDEA.
 * User: rpandey
 * Date: May 14, 2003
 * Time: 4:39:30 PM
 * To change this template use Options | File Templates.
 */
public class LuceneDocumentBaseOAIHarvester extends AbstractDocumentBaseOAIHarvester {


    public LuceneDocumentBaseOAIHarvester(LuceneDocumentBase base) {
        super(base);
    }

    /////redo these methods

    /*TODO? : why did i put this here, doesn't it belong in an oaiRepository class?-rbp
    public void purgeDeletedRecords() {
        try {
            LuceneIndex luceneSearchIndex = getSearchIndex();
            luceneSearchIndex.delete(new Term(LuceneDocumentBase.OAI_DELETED_RECORD, INTERNAL_FIELD_VALE_WILDCARD_ASTERIX));
            luceneSearchIndex.optimize();
        } catch (SDXException e) {
            Utilities.logException(logger, e);
        }

    } */

}

==> sdx-2.3-src.zip: sdx-2.3/src/java/fr/gouv/culture/sdx/oai/LuceneDocumentBaseOAIHarvester.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.oai;

import fr.gouv.culture.sdx.documentbase.LuceneDocumentBase;

/**
 * Created by IntelliJ IDEA.
 * User: rpandey
 * Date: May 14, 2003
 * Time: 4:39:30 PM
 * To change this template use Options | File Templates.
 */
public class LuceneDocumentBaseOAIHarvester extends AbstractDocumentBaseOAIHarvester {


    public LuceneDocumentBaseOAIHarvester(LuceneDocumentBase base) {
        super(base);
    }
    
    public void close(){
    	super.close();
    }

    /////redo these methods

    /*TODO? : why did i put this here, doesn't it belong in an oaiRepository class?-rbp
    public void purgeDeletedRecords() {
        try {
            LuceneIndex luceneSearchIndex = getSearchIndex();
            luceneSearchIndex.delete(new Term(LuceneDocumentBase.OAI_DELETED_RECORD, INTERNAL_FIELD_VALE_WILDCARD_ASTERIX));
            luceneSearchIndex.optimize();
        } catch (SDXException e) {
            Utilities.logException(super.getLog(), e);
        }

    } */

}
